
#################################
# income analysis
#################################

rm(list=ls())                                      # clear memory
setwd("/pol280")                                  # set working directory

library(haven)
dat <- read_dta("fmli164.dta")                     # load in the CES data

head(dat$fincbtxm)                                 # look at household income before taxes

plot(density(dat$fincbtxm))                        # plot household income probability density
hist(dat$fincbtxm, breaks=50)                      # plot related histogram

zero <- ifelse(dat$fincbtxm == 0, 1, 0)            # check people making zero income
sum(zero)

mean(dat$fincbtxm)                                 # mean of household income before taxes

summary(dat$fincbtxm)                              # calculate mean of salaries
sd(dat$fincbtxm, na.rm=T)                          # calculate std. deviation of salaries
76968.25/sqrt(6301)                                # calculate std. error of mean salary
(72886.41 - 76000)/969.6318                        # calculate z-statistic                          
pnorm(-3.211105, lower.tail=T)                     # calculate the p-value under the null
pt( -3.211105, df=6300, lower.tail=T)              # calculate the p-value using the t-density

t.test(dat$fincbtxm)                               # one-step t-testing
t.test(dat$fincbtxm, mu = 76000)
confint(lm(dat$fincbtxm~1))




###################################
# compare normal and t-densities
###################################

rm(list=ls())                                           # clear memory

x <- seq(from=-2.5, to=2.5, by=0.1)
plot( dnorm(x, mean=0, sd=1) ~ x, type="l")
plot( dt(x, df=10) ~ x, type="l")
plot( dt(x, df=20) ~ x, type="l")
plot( dt(x, df=60) ~ x, type="l")

x <- seq(from=-4.5, to=4.5, by=0.1)
hist(rnorm(1000, mean=0, sd=1), freq=F, ylim=c(0, 0.45), xlim=c(-3.5, 3.5))
lines(dnorm(x, mean=0, sd=1) ~ x, lty=2)
lines(dt(x, df=10) ~ x, lty=2, col="red")

x <- seq(from=-4.5, to=4.5, by=0.1)
hist(rt(1000, df=30), freq=F, ylim=c(0, 0.45), xlim=c(-3.5, 3.5))
lines(dt(x, df=30) ~ x, lty=2)
